@@ -10,6 +10,7 @@ from pathlib import Path
 from nextcode.exceptions import ServerError
 from nextcode.services.query.exceptions import TemplateError
 
+from ...queryapi import get_results
 from ...utils import print_tab, dumps, get_logger, abort
 
 log = get_logger(name='commands.query', level='INFO')
@@ -33,7 +34,10 @@ def templates():
 @click.pass_context
 def list(ctx, organization, category, is_raw):
     """
+    Show a list of all templates registered into the system
 
+    The list can optionally be filtered and output as json for additional
+    processing.
     """
     svc = ctx.obj.service
     all_templates = svc.get_templates(organization=organization, category=category)
@@ -81,6 +85,18 @@ def delete(ctx, name):
 @click.option('--args', 'is_args', is_flag=True, default=False, help='View arguments')
 @click.pass_context
 def view(ctx, name, is_raw, is_yaml, is_args):
+    """
+    View details about a single template
+
+    Use the full name of the template including organization, 
+    category and version, i.e. [org]/[cat]/[name]/[version]
+
+    If you omit the version the latest version is fetched.
+    e.g. 'nextcode query templates view wxnc/system/acmg_scores'
+
+    You can also specify a glob pattern. e.g. 
+    'nextcode query templates view "wxnc/system/acmg_scores/1.4.*"'
+    """
     svc = ctx.obj.service
     try:
         template = svc.get_template(name)
@@ -145,18 +161,11 @@ def add(ctx, filename, replace):
     click.echo("View the template with: nextcode query templates view {}".format(full_name))
 
 
-@templates.command(context_settings=dict(ignore_unknown_options=True))
-@click.argument('name', nargs=1)
-@click.argument('args', nargs=-1, type=click.UNPROCESSED)
-@click.pass_context
-def render(ctx, name, args):
-    """Render a query from template
-    """
-    svc = ctx.obj.service
+def _render(svc, name, args):
     try:
         _ = svc.get_template(name)
-    except ServerError:
-        abort("Template {} not found".format(name))
+    except TemplateError as ex:
+        abort(str(ex))
     params = {}
     for a in args:
         lst = a.split("=", 1)
@@ -176,4 +185,86 @@ def render(ctx, name, args):
             sys.exit(1)
         else:
             abort(ex)
+    return query_string, params
+
+
+@templates.command(context_settings=dict(ignore_unknown_options=True))
+@click.argument('name', nargs=1)
+@click.argument('args', nargs=-1, type=click.UNPROCESSED)
+@click.pass_context
+def render(ctx, name, args):
+    """
+    Render a query from template
+
+    View the query that will be generated from the template with
+    the specified parameters.
+
+    Use the full name of the template in the form
+    [org]/[cat]/[name]/[version (optional)]
+
+    Example:
+    'nextcode query templates render wxnc/category/template/1.0.0 arg1=1 arg2=2'
+
+    """
+    svc = ctx.obj.service
+    query_string, _ = _render(svc, name, args)
+
     click.echo(query_string)
+
+
+@templates.command(context_settings=dict(ignore_unknown_options=True))
+@click.argument('name', nargs=1)
+@click.argument('args', nargs=-1, type=click.UNPROCESSED)
+@click.option('-o', '--output', 'output_file', help='File to write results to (otherwise output to console)')
+@click.option('-l', '--limit', 'limit', default=0, help='Limit the number of rows returned', show_default=True)
+@click.option(
+    '-n',
+    '--nowait',
+    is_flag=True,
+    default=False,
+    help='Run command without waiting for it to finish',
+)
+@click.option(
+    '--raw', 'is_raw', is_flag=True, default=False, help='Raw JSON response from endpoint'
+)
+@click.pass_context
+def execute(ctx, name, args, output_file, limit, nowait, is_raw):
+    """
+    Execute a template
+
+    Execute a query that will be generated from the template with
+    the specified parameters.
+
+    Use the full name of the template in the form
+    [org]/[cat]/[name]/[version (optional)]
+
+    Example:
+    'nextcode query templates execute wxnc/category/template/1.0.0 arg1=1 arg2=2'
+
+    """
+    svc = ctx.obj.service
+    # render the template to ensure it is okay.
+    query_string, params = _render(svc, name, args)
+
+    qry = svc.execute_template(name, **params, nowait=True)
+    if not nowait:
+        qry.wait()
+
+    if qry.failed:
+        click.secho(
+            "Query {} failed with message: {}".format(qry.query_id, qry.status_message), fg="red"
+        )
+        return
+    if is_raw:
+        click.echo(dumps(qry.raw))
+        return
+
+    if qry.running:
+        click.echo("Query {} is now running.".format(qry.query_id))
+        click.echo("View query process with: nextcode query info {}".format(qry.query_id))
+        return
+    click.secho(
+        "Query {} completed successfully in {} ms".format(qry.query_id, qry.duration), fg="green"
+    )
+
+    get_results(qry, limit, None, None, output_file)
