@@ -68,8 +68,8 @@ def inspect(ctx, is_raw):
         echo(dumps(curr_status))
         return
     print_tab('Job id', workflow_job.job_id)
-    status = workflow_job.status or 'N/A'
-    print_tab('Job status', status)
+    job_status = workflow_job.status or 'N/A'
+    print_tab('Job status', job_status)
     print_tab('Status message', workflow_job.status_message)
     latest_event = curr_status['latest_event']
     event_too_old = False
@@ -94,7 +94,7 @@ def inspect(ctx, is_raw):
             executor_pod = pod
             break
     if not executor_pod:
-        if status in ('PENDING', 'STARTED'):
+        if job_status in ('PENDING', 'STARTED'):
             secho("Nextflow executor pod not Found. This job is not running!", fg='red')
     else:
         status = executor_pod['status']
@@ -153,9 +153,9 @@ def inspect(ctx, is_raw):
             )
         )
 
-    if status == 'COMPLETED':
+    if job_status == 'COMPLETED':
         secho("\nThis job appears to have completed successfully", fg='green', bold=True)
-    elif status in ('STARTED', 'PENDING'):
+    elif job_status in ('STARTED', 'PENDING'):
         if not executor_pod:
             secho("\nThis job appears to be broken", fg='red', bold=True)
         else:
@@ -174,9 +174,9 @@ def inspect(ctx, is_raw):
             except Exception:
                 secho("\nThis job appears to be broken", fg='red', bold=True)
     else:
-        secho("\nJob is not in running state", bold=True)
+        secho("\nJob is not in running state (%s)" % job_status, bold=True)
 
-    if executor_pod and status == 'PENDING':
+    if executor_pod and job_status == 'PENDING':
         cmd = ['nextcode', 'workflow', 'job', str(workflow_job.job_id), 'logs', 'pod']
         echo("\nExecuting %s..." % ' '.join(cmd))
         subprocess.call(cmd)
@@ -635,6 +635,7 @@ def link(ctx, link_type):
     Helper that produces a link to external monitoring tools with filters
     preconfigured for this job
     """
+
     workflow_job = ctx.obj.job
 
     start_date = workflow_job.submit_date
@@ -645,23 +646,20 @@ def link(ctx, link_type):
     job_id = workflow_job.job['job_id']
     profile_name = get_default_profile()
     if link_type == 'kibana':
+        kibana_url = ctx.obj.session.url_from_endpoint("kibana")
+
         start_date = start_date.isoformat()
         end_date = end_date.isoformat()
-        cluster_name = profile_name
-        kibana_url = "https://d0c059b7c4864f6c8cc009a5a3c795b3.us-east-1.aws.found.io:9243/s/{cluster_name}".format(
-            cluster_name=cluster_name
-        )
         link = (
-            "{kibana_url}/app/kibana#/discover?_g=(refreshInterval:(pause:!t,value:0),"
+            "{kibana_url}/discover?_g=(refreshInterval:(pause:!t,value:0),"
             "time:(from:'{start_date}',mode:absolute,to:'{end_date}'))"
-            "&_a=(columns:!(kubernetes.labels.taskName,message),index:'filebeat-{cluster_name}-*',interval:auto,"
+            "&_a=(columns:!(kubernetes.labels.taskName,message),interval:auto,"
             "query:(language:lucene,query:'kubernetes.labels.job-id:{job_id}%20%26%26%20kubernetes.labels.started-by:workflow-service'),"
             "sort:!('@timestamp',desc))".format(
                 kibana_url=kibana_url,
                 start_date=start_date,
                 end_date=end_date,
                 job_id=job_id,
-                cluster_name=cluster_name,
             )
         )
         echo(link)
